# Generated by Django 5.2.4 on 2025-07-15 04:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('post_office', '0012_alter_attachment_file_storage'),
    ]

    operations = [
        migrations.AddField(
            model_name='email',
            name='recipient_delivery_status',
            field=models.PositiveSmallIntegerField(blank=True, choices=[(10, 'Accepted'), (20, 'Delivered'), (30, 'Opened'), (40, 'Clicked'), (50, 'Deferred'), (60, 'Soft Bounced'), (70, 'Hard Bounced'), (80, 'Spam Complaint'), (90, 'Unsubscribed')], null=True, verbose_name='Recipient Delivery Status'),
        ),
        migrations.AlterField(
            model_name='log',
            name='status',
            field=models.PositiveSmallIntegerField(choices=[(0, 'sent'), (1, 'failed'), (10, 'Accepted'), (20, 'Delivered'), (30, 'Opened'), (40, 'Clicked'), (50, 'Deferred'), (60, 'Soft Bounced'), (70, 'Hard Bounced'), (80, 'Spam Complaint'), (90, 'Unsubscribed')], verbose_name='Status'),
        ),
    ]



# Generated by Django 5.1 on 2025-05-27 23:00

import post_office.models
import post_office.settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('post_office', '0011_models_help_text'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(
                storage=post_office.settings.get_file_storage,
                upload_to=post_office.models.get_upload_path,
                verbose_name='File',
            ),
        ),
    ]
